import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  curveBasis
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const title = 'London Monthly Roadside PM2.5  Particulate';
  
  const xValue = d => d.Month;
  const xAxisLabel = 'Time (Months)';
  
  const yValue = d => d['Roadside_PM2.5'];
  const circleRadius = 6;
  const yAxisLabel = 'PM2.5 (ug/m3)';
  
  const margin = { top: 60, right: 40, bottom: 88, left: 105 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();
  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
    .nice();
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -60)
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 80)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
  const lineGenerator = line()
    .x(d => xScale(xValue(d)))
    .y(d => yScale(yValue(d)))
    .curve(curveBasis);
  
  g.append('path')
      .attr('class', 'line-path')
      .attr('d', lineGenerator(data));
  
//make line to show limit
  g.append("line")          
    .style("stroke", "red")
    .attr("x1", xScale(xValue))
    .attr("y1", yScale(10))
    .attr("x2", 814)
    .attr("y2", yScale(10));
  
  g.append('text')
      //.attr('class', 'axis-label')
      .attr('y', yScale(10)-5)
      .attr('x', innerWidth / 2 - 400)
      .attr('fill', 'red')
      .text("World Health Org. Limit");
  
  g.append('text')
      .attr('class', 'title')
      .attr('y', -10)
      .text(title);
};

csv('https://vizhub.com/KCachel/datasets/londonairqualityjan2010aug2018Dates.csv')
  .then(data => {

    data.forEach(d => {
    d.Month = new Date(d.Month);
    d.Roadside_NitricOxide = +d.Roadside_NitricOxide;
    d.Roadside_NitrogenDioxide = +d.Roadside_NitrogenDioxide;
    d.Roadside_OxidesofNitrogen = +d.Roadside_OxidesofNitrogen;
    d.Roadside_Ozone = +d.Roadside_Ozone;
    d.Roadside_PM10 = +d.Roadside_PM10;
    d['Roadside_PM2.5'] = +d['Roadside_PM2.5']; 
    d.Roadside_SulphurDioxide = +d.Roadside_SulphurDioxide;
    d.Background_NitricOxide = +d.Background_NitricOxide;
    d.Background_NitrogenDioxide = +d.Background_NitrogenDioxide;
    d.Background_OxidesofNitrogen = +d.Background_OxidesofNitrogen;
    d.Background_Ozone = +d.Background_Ozone;
    d.Background_PM10 = +d.Background_PM10;
    d['Background_PM2.5'] = +d['Background_PM2.5'];
    d.Background_SulphurDioxide = d.Background_SulphurDioxide;

      
      
      
    });
    render(data);
  });